#
# spec file for package ghc-hackage-security
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name hackage-security
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.5.3.0
Release:        lp151.1.2
Summary:        Hackage security library
License:        BSD-3-Clause
Group:          Development/Libraries/Haskell
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
Source1:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/revision/3.cabal#/%{pkg_name}.cabal
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-base16-bytestring-devel
BuildRequires:  ghc-base64-bytestring-devel
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-cryptohash-sha256-devel
BuildRequires:  ghc-directory-devel
BuildRequires:  ghc-ed25519-devel
BuildRequires:  ghc-filepath-devel
BuildRequires:  ghc-mtl-devel
BuildRequires:  ghc-network-devel
BuildRequires:  ghc-network-uri-devel
BuildRequires:  ghc-parsec-devel
BuildRequires:  ghc-pretty-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-tar-devel
BuildRequires:  ghc-template-haskell-devel
BuildRequires:  ghc-time-devel
BuildRequires:  ghc-transformers-devel
BuildRequires:  ghc-zlib-devel
%if %{with tests}
BuildRequires:  ghc-QuickCheck-devel
BuildRequires:  ghc-tasty-devel
BuildRequires:  ghc-tasty-hunit-devel
BuildRequires:  ghc-tasty-quickcheck-devel
BuildRequires:  ghc-temporary-devel
%endif

%description
The hackage security library provides both server and client utilities for
securing the Hackage package server (<http://hackage.haskell.org/>).
It is based on The Update Framework (<http://theupdateframework.com/>), a set
of recommendations developed by security researchers at various universities in
the US as well as developers on the Tor project
(<https://www.torproject.org/>).

The current implementation supports only index signing, thereby enabling
untrusted mirrors. It does not yet provide facilities for author package
signing.

The library has two main entry points: "Hackage.Security.Client" is the main
entry point for clients (the typical example being 'cabal'), and
"Hackage.Security.Server" is the main entry point for servers (the typical
example being 'hackage-server').

%package devel
Summary:        Haskell %{pkg_name} library development files
Group:          Development/Libraries/Haskell
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development
files.

%prep
%setup -q -n %{pkg_name}-%{version}
cp -p %{SOURCE1} %{pkg_name}.cabal

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc ChangeLog.md

%changelog
* Fri Oct 19 2018 Peter Simons <psimons@suse.com>
- Update Cabal build instructions to support ghc-8.6.1.
* Tue Aug  7 2018 psimons@suse.com
- Update Cabal build information to support Cabal 2.4.x.
* Wed Jul 18 2018 psimons@suse.com
- Cosmetic: replace tabs with blanks, strip trailing white space,
  and update copyright headers with spec-cleaner.
* Wed Jul 18 2018 psimons@suse.com
- Revise cabal build file to specify more accurate dependencies.
* Mon May 14 2018 psimons@suse.com
- Update hackage-security to version 0.5.3.0.
  * Use `flock(2)`-based locking where available
    (compat-shim taken from `cabal-install`'s code-base) (#207)
  * Improve handling of async exceptions (#187)
  * Detect & recover from local corruption of uncompressed index tarball (#196)
  * Support `base-4.11`
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Mon May 22 2017 psimons@suse.com
- Update to version 0.5.2.2 revision 4 with cabal2obs.
* Wed Apr 19 2017 psimons@suse.com
- Update to version 0.5.2.2 revision 3 with cabal2obs.
* Mon Feb 20 2017 psimons@suse.com
- Update to version 0.5.2.2 revision 2 with cabal2obs.
* Wed Dec 28 2016 psimons@suse.com
- Update to version 0.5.2.2 revision 1 with cabal2obs.
* Fri Sep 16 2016 psimons@suse.com
- Update to version 0.5.2.2 with cabal2obs.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 0.5.2.1 revision 0 with cabal2obs.
* Fri May 27 2016 mimi.vx@gmail.com
- ghc-hackage-security generated by st2obs scritpt
